<?php

use WHMCS\Database\Capsule as DB;

class BalanceWidgetAPI {

    protected $resellerID;
    protected $apiKey;
    protected $soap;

    public function getApiKey() {
        return $this->apiKey;
    }

    public function getResellerID() {
        return $this->resellerID;
    }

    public function __construct($resellerID, $apiKey) {
        $this->soap = new SoapClient(NULL, array("location" => "https://api.synergywholesale.com", "uri" => "", 'trace' => true));
        $this->apiKey = $apiKey;
        $this->resellerID = $resellerID;
    }

    public function request($command, $params = array()) {
        $params['resellerID'] = $this->getResellerID();
        $params['apiKey'] = $this->getApiKey();
        try {
            $response = $this->soap->$command($params);
        } catch (Exception $ex) {
            
        }
        return $response;
    }

    public function balanceQuery() {
        $command = "balanceQuery";
        $response = $this->request($command);
        return $response;
    }

}

class BalanceWidget extends \WHMCS\Module\AbstractWidget {

    protected $title = 'Synergy Wholesale Available Balance';
    protected $description = '';
    protected $weight = 150;
    protected $columns = 1;
    protected $cache = false;
    protected $cacheExpiry = 120;
    protected $requiredPermission = '';

    public function getData() {
        
        $query = DB::table('tbladdonmodules')
                ->where('module', 'synergywholesale_balance')
                ->select('setting', 'value')
                ->get();

        $result = [];

        foreach ($query as $data) {
            if ($data->setting == "api_key") $result['api_key'] = $data->value;
            if ($data->setting == "reseller_id") $result['reseller_id'] = $data->value;
        }

        return $result;
    }

    public function generateOutput($result) {
        $content = "";

        if (isset($result['api_key']) && isset($result['reseller_id']) && $result['api_key'] != "" && $result['reseller_id'] != "") {
            $api = new BalanceWidgetAPI($result['reseller_id'], $result['api_key']);

            $apiResult = $api->balanceQuery();
            if ($balance = $apiResult->balance) {
                $content .= "<div style='text-align: center; color: green; font-weight: bold; font-size: 18px; padding: 16px;'>Balance: $" . number_format($balance, 2) . "</div>";
            }
        }

        return $content;
    }
}

add_hook("AdminHomeWidgets", 1, function() {
    return new BalanceWidget();
});

?>